==> flink-1.12.7-src.tgz: flink-1.12.7/flink-python/src/main/java/org/apache/flink/table/runtime/arrow/vectors/ArrowSmallIntColumnVector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.runtime.arrow.vectors;

import org.apache.flink.annotation.Internal;
import org.apache.flink.table.data.vector.ShortColumnVector;
import org.apache.flink.util.Preconditions;

import org.apache.arrow.vector.SmallIntVector;

/** Arrow column vector for Int. */
@Internal
public final class ArrowSmallIntColumnVector implements ShortColumnVector {

    private final SmallIntVector smallIntVector;

    public ArrowSmallIntColumnVector(SmallIntVector smallIntVector) {
        this.smallIntVector = Preconditions.checkNotNull(smallIntVector);
    }

    @Override
    public short getShort(int i) {
        return smallIntVector.get(i);
    }

    @Override
    public boolean isNullAt(int i) {
        return smallIntVector.isNull(i);
    }
}

==> flink-1.20.3-src.tgz: flink-1.20.3/flink-python/src/main/java/org/apache/flink/table/runtime/arrow/vectors/ArrowSmallIntColumnVector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.runtime.arrow.vectors;

import org.apache.flink.annotation.Internal;
import org.apache.flink.table.data.columnar.vector.ShortColumnVector;
import org.apache.flink.util.Preconditions;

import org.apache.arrow.vector.SmallIntVector;

/** Arrow column vector for Int. */
@Internal
public final class ArrowSmallIntColumnVector implements ShortColumnVector {

    private final SmallIntVector smallIntVector;

    public ArrowSmallIntColumnVector(SmallIntVector smallIntVector) {
        this.smallIntVector = Preconditions.checkNotNull(smallIntVector);
    }

    @Override
    public short getShort(int i) {
        return smallIntVector.get(i);
    }

    @Override
    public boolean isNullAt(int i) {
        return smallIntVector.isNull(i);
    }
}
